@@ -1,6 +1,6 @@
 /*
     orzcharlist
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
 #include "orzcharlist.h"
 #include "orzcharset.h"
 #include "misc/charuty.h"
-#include <gdk/gdkkeysyms.h>
 
 
 enum
@@ -59,7 +58,7 @@ orz_charlist_class_init (OrzCharlistClass *klass)
                                 G_TYPE_NONE, 0);
 
   binding_set = gtk_binding_set_by_class (klass);
-  gtk_binding_entry_add_signal (binding_set, GDK_Escape, 0, "escape", 0);
+  gtk_binding_entry_add_signal (binding_set, GDK_KEY_Escape, 0, "escape", 0);
 }
 
 
@@ -245,7 +244,7 @@ static void
 orz_charlist_activate (GtkWidget   *widget,
                        OrzCharlist *charlist)
 {
-  if (GTK_WIDGET_IS_SENSITIVE (charlist->ok_button))
+  if (gtk_widget_is_sensitive (charlist->ok_button))
     orz_charlist_clicked_add (widget, charlist);
 }
 
@@ -294,8 +293,8 @@ orz_charlist_dialog_drag_end (GtkWidget      *widget,
 static void
 orz_charlist_escape (OrzCharlist *charlist)
 {
-  if (GTK_WIDGET_VISIBLE (charlist->cancel_button)
-                            && GTK_WIDGET_SENSITIVE (charlist->cancel_button))
+  if (gtk_widget_get_visible (charlist->cancel_button)
+                        && gtk_widget_get_sensitive (charlist->cancel_button))
     g_signal_emit_by_name (G_OBJECT (charlist->cancel_button), "clicked");
 }
 
@@ -306,8 +305,8 @@ orz_charlist_delete (GtkWidget *widget,
                      GdkEvent  *event,
                      gpointer   user_data)
 {
-  if (GTK_WIDGET_VISIBLE (ORZ_CHARLIST (widget)->cancel_button)
-                && GTK_WIDGET_SENSITIVE (ORZ_CHARLIST (widget)->cancel_button))
+  if (gtk_widget_get_visible (ORZ_CHARLIST (widget)->cancel_button)
+            && gtk_widget_get_sensitive (ORZ_CHARLIST (widget)->cancel_button))
     g_signal_emit_by_name
                 (G_OBJECT (ORZ_CHARLIST (widget)->cancel_button), "clicked");
   return TRUE;
@@ -383,8 +382,8 @@ orz_charlist_init (OrzCharlist *charlist)
   g_signal_connect (G_OBJECT (charlist->down_button), "clicked",
                         G_CALLBACK (orz_charlist_clicked_down), charlist);
   /* ja:ボックス */
-  vbox = gtk_vbox_new (FALSE, SPACING);
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
+  vbox = gtk_dialog_get_content_area (GTK_DIALOG (charlist));
+  gtk_box_set_spacing (GTK_BOX (vbox), SPACING);
   gtk_box_pack_start (GTK_BOX (vbox), scroll, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), charlist->charset, FALSE, FALSE, 0);
   hbox = gtk_hbox_new (FALSE, SPACING);
@@ -394,7 +393,6 @@ orz_charlist_init (OrzCharlist *charlist)
   gtk_box_pack_start (GTK_BOX (hbox), charlist->up_button, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), charlist->down_button, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (charlist)->vbox), vbox);
 
   /* ja:表示 */
   gtk_widget_set_sensitive (charlist->add_button, FALSE);
