@@ -1,10 +1,10 @@
 /*
     Text maid
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "charset.h"
 #include "edit.h"
@@ -110,11 +109,12 @@ gint
 edit_get_width_max (TmaidWindow *tmaid)
 {
   gint y, data_pos, width, max = 0;
+  GtkAllocation allocation;
   LineBuffer *p;
 
+  gtk_widget_get_allocation (tmaid->drawing, &allocation);
   for (y = 0, p = edit_get_line_buf (&tmaid->start, &tmaid->off, tmaid->top.y);
-                                    y < tmaid->drawing->allocation.height && p;
-                                        y += tmaid->font_height, p = p->next)
+            y < allocation.height && p; y += tmaid->font_height, p = p->next)
     {
       width = 0;
       data_pos = 0;
