@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -131,7 +131,7 @@ file_open_text (const gchar *file,
         gssize bytes_read_prev = -1;
 
         buffer = g_memdup (inbuf, length);
-        while ((g_clear_error (&error),
+        while (abort_break && (g_clear_error (&error),
                 !(outbuf = g_convert (buffer, length, "UTF-8", charset[i],
                                         &bytes_read, &bytes_written, &error)))
                                     && bytes_read_prev != bytes_read && error
@@ -253,19 +253,19 @@ file_open_text (const gchar *file,
   g_free (outbuf);
   /* ja:変換 */
   if (tmaid->ft.html)
-    for (p = tmaid->start; p; p = p->next)
+    for (p = tmaid->start; abort_break && p; p = p->next)
       {
         while (gtk_events_pending ())
           gtk_main_iteration ();
         i = 0;
-        while (i + 4 <= p->length)
+        while (abort_break && i + 4 <= p->length)
           if (p->text[i++] == '&' && p->text[i++] == '#')
             {
               c = 0;
               if (g_ascii_tolower (p->text[i]) == 'x')
                 {
                   /* ja:16進数 */
-                  for (j = i + 1; j < p->length; j++)
+                  for (j = i + 1; abort_break && j < p->length; j++)
                     if (g_ascii_isxdigit (p->text[j]))
                       c = c * 16 + g_ascii_xdigit_value (p->text[j]);
                     else
@@ -274,7 +274,7 @@ file_open_text (const gchar *file,
               else
                 {
                   /* ja:10進数 */
-                  for (j = i; j < p->length; j++)
+                  for (j = i; abort_break && j < p->length; j++)
                     if (g_ascii_isdigit (p->text[j]))
                       c = c * 10 + g_ascii_digit_value (p->text[j]);
                     else
@@ -294,7 +294,7 @@ file_open_text (const gchar *file,
             }
       }
   else if (tmaid->ft.esc)
-    for (p = tmaid->start; p; p = p->next)
+    for (p = tmaid->start; abort_break && p; p = p->next)
       {
         while (gtk_events_pending ())
           gtk_main_iteration ();
@@ -303,7 +303,7 @@ file_open_text (const gchar *file,
           if (p->text[i++] == '\\' && p->text[i++] == 'u')
             {
               c = 0;
-              for (j = i; j < p->length; j++)
+              for (j = i; abort_break && j < p->length; j++)
                 if (g_ascii_isxdigit (p->text[j]))
                   c = c * 16 + g_ascii_xdigit_value (p->text[j]);
                 else
