@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -65,8 +65,10 @@ property_copy (FileType *ft_dst,
   g_free (ft_dst->font_name);
   ft_dst->font_name = ft_src->font_name ? g_strdup (ft_src->font_name) : NULL;
   g_memmove (ft_dst->color, ft_src->color, sizeof (GdkColor) * 12);
+#if ! GTK_CHECK_VERSION(3,0,0)
   gdk_colormap_alloc_colors (gdk_colormap_get_system (),
                                     ft_dst->color, 12, FALSE, TRUE, success);
+#endif /* not GTK_CHECK_VERSION(3,0,0) */
 }
 
 
@@ -79,6 +81,7 @@ property_change (TmaidWindow *tmaid,
 {
   gboolean modify;
   gint max, sx, sy;
+  GtkAllocation allocation;
 
   if (tmaid->ft.limit != ft->limit || tmaid->ft.tab != ft->tab
                         || (tmaid->ft.code && tmaid->ft.margin != ft->margin))
@@ -117,8 +120,9 @@ property_change (TmaidWindow *tmaid,
       modify_margin (tmaid);
     }
   /* ja:スクロールバー */
-  sx = MAX (tmaid->drawing->allocation.width / tmaid->font_width, 1);
-  sy = MAX (tmaid->drawing->allocation.height / tmaid->font_height, 1);
+  gtk_widget_get_allocation (tmaid->drawing, &allocation);
+  sx = MAX (allocation.width / tmaid->font_width, 1);
+  sy = MAX (allocation.height / tmaid->font_height, 1);
   if (tmaid->top.y > tmaid->max - sy)
     tmaid->top.y = MAX (tmaid->max - sy, 0);
   max = edit_get_width_max (tmaid);
@@ -281,8 +285,8 @@ property_dialog_clicked_color (GtkWidget      *widget,
                                                                         &iter))
       {
         gtk_color_selection_set_current_color (GTK_COLOR_SELECTION
-                            (GTK_COLOR_SELECTION_DIALOG (dialog)->colorsel),
-                                                    propdlg->gdk_color + i);
+                                (gtk_color_selection_dialog_get_color_selection
+            (GTK_COLOR_SELECTION_DIALOG (dialog))), propdlg->gdk_color + i);
         break;
       }
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
@@ -291,7 +295,8 @@ property_dialog_clicked_color (GtkWidget      *widget,
       GdkColor color;
 
       gtk_color_selection_get_current_color (GTK_COLOR_SELECTION
-                    (GTK_COLOR_SELECTION_DIALOG (dialog)->colorsel), &color);
+                                (gtk_color_selection_dialog_get_color_selection
+                            (GTK_COLOR_SELECTION_DIALOG (dialog))), &color);
       xpm[0] = "24 16 1 1";
       for (i = 2; i < 18; i++)
         xpm[i] = "XXXXXXXXXXXXXXXXXXXXXXXX";
@@ -703,12 +708,22 @@ property_dialog (GtkWindow *parent,
     }
   /* ja:コンボボックス */
 #if GTK_CHECK_VERSION(2,4,0)
+# if GTK_CHECK_VERSION(2,24,0)
+  propdlg.combo = gtk_combo_box_text_new ();
+  gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (propdlg.combo), "CR+LF");
+  gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (propdlg.combo), "CR");
+  gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (propdlg.combo), "LF");
+  if (ft->text && ft->ext)
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (propdlg.combo),
+                                                                    _("Auto"));
+# else /* not GTK_CHECK_VERSION(2,24,0) */
   propdlg.combo = gtk_combo_box_new_text ();
   gtk_combo_box_append_text (GTK_COMBO_BOX (propdlg.combo), "CR+LF");
   gtk_combo_box_append_text (GTK_COMBO_BOX (propdlg.combo), "CR");
   gtk_combo_box_append_text (GTK_COMBO_BOX (propdlg.combo), "LF");
   if (ft->text && ft->ext)
     gtk_combo_box_append_text (GTK_COMBO_BOX (propdlg.combo), _("Auto"));
+# endif /* not GTK_CHECK_VERSION(2,24,0) */
   gtk_combo_box_set_active (GTK_COMBO_BOX (propdlg.combo), ft->crlf);
   g_signal_connect (G_OBJECT (propdlg.combo), "changed",
                         G_CALLBACK (property_dialog_ok_sensitive), &propdlg);
@@ -1027,8 +1042,8 @@ property_dialog (GtkWindow *parent,
   gtk_box_pack_start (GTK_BOX (vbox), frame6, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 
-  vbox = gtk_vbox_new (FALSE, SPACING);
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
+  vbox = gtk_dialog_get_content_area (GTK_DIALOG (propdlg.dialog));
+  gtk_box_set_spacing (GTK_BOX (vbox), SPACING);
   gtk_box_pack_start (GTK_BOX (vbox), tbox, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
   hbox = gtk_hbox_new (FALSE, SPACING);
@@ -1044,8 +1059,6 @@ property_dialog (GtkWindow *parent,
                                     propdlg.check_associate, FALSE, FALSE, 0);
   gtk_box_pack_end (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (propdlg.dialog)->vbox), vbox);
-
   /* ja:表示 */
   gtk_widget_set_sensitive (propdlg.button_color, FALSE);
   gtk_widget_set_sensitive (propdlg.radio_upper, ft->writemode >= 3);
@@ -1165,8 +1178,10 @@ property_dialog (GtkWindow *parent,
           propdlg.charset_list = NULL;
         }
       g_memmove (ft->color, propdlg.gdk_color, sizeof (GdkColor) * 12);
+#if ! GTK_CHECK_VERSION(3,0,0)
       gdk_colormap_alloc_colors (gdk_colormap_get_system (),
                                         ft->color, 12, FALSE, TRUE, success);
+#endif /* not GTK_CHECK_VERSION(3,0,0) */
       g_free (ft->font_name);
 #if GTK_CHECK_VERSION(2,4,0)
       ft->font_name = g_strdup (gtk_font_button_get_font_name
