@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,6 +26,9 @@
 #include "misc/misc.h"
 #include "orz/orzhistory.h"
 #include "orz/orzmdi.h"
+#if GLIB_CHECK_VERSION(2,16,0)
+# include <gio/gio.h>
+#endif /* GLIB_CHECK_VERSION(2,16,0) */
 
 
 /******************************************************************************
@@ -171,16 +174,31 @@ signal_drag_data_received (GtkWidget        *widget,
     {
       gint i;
 
-      for (i = 0; files[i]; i++)
+      for (i = 0; files[i] && *files[i] !='\0'; i++)
         {
+#if GLIB_CHECK_VERSION(2,16,0)
+          GFile *gfile;
+
+          gfile = g_file_new_for_uri (files[i]);
+          if (gfile)
+            {
+              gchar *file;
+
+              file = g_file_get_path (gfile);
+              g_object_unref (gfile);
+#else /* not GLIB_CHECK_VERSION(2,16,0) */
           gchar *file;
 
           file = g_filename_from_uri (files[i], NULL, NULL);
-          if (file)
-            {
-              file_open_edit (file);
-              g_free (file);
+#endif /* not GLIB_CHECK_VERSION(2,16,0) */
+              if (file)
+                {
+                  file_open_edit (file);
+                  g_free (file);
+                }
+#if GLIB_CHECK_VERSION(2,16,0)
             }
+#endif /* GLIB_CHECK_VERSION(2,16,0) */
         }
       g_strfreev (files);
     }
